==> aima-2014.0.tar.gz: aima-2014.0/aima/__init__.py <==
# Copyright (C) 2009-2014 Peter Norvig <peter.norvig@gmail.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
"""aima -- Artificial Intelligence, A Modern Approach, by Stuart Russell and Peter Norrvig"""

__version__ = '2014.0'
__authors__ = [
    'Peter Norvig <peter.norvig@gmail.com>',
    'Withal <withal@gmail.com>',
    'Spotted Metal? <spottedMetal@gmail.com>',
    'S R Burnet? <srburnet@gmail.com>',
    'Phil Ruggera',
    'Peng Shao',
    'Amit Patil',
    'Ted Nienstedt',
    'Jim Martin',
    'Ben Catanzariti',
    ]
__github_url__ = "https://github.com/hobson/%s" % (__name__)

==> aima-2014.1.tar.gz: aima-2014.1/aima/__init__.py <==
# Copyright (C) 2009-2014 Peter Norvig <peter.norvig@gmail.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
"""aima -- Artificial Intelligence, A Modern Approach, by Stuart Russell and Peter Norrvig"""

__version__ = '2014.1'
__authors__ = [
    'Peter Norvig <peter.norvig@gmail.com>',
    'Darius Bacon <withal@gmail.com>',
    'Spotted Metal? <spottedMetal@gmail.com>',
    'S R Burnet? <srburnet@gmail.com>',
    'Phil Ruggera',
    'Peng Shao',
    'Amit Patil',
    'Ted Nienstedt',
    'Jim Martin',
    'Ben Catanzariti',
    ]
__github_url__ = "https://github.com/hobson/%s" % (__name__)
